@@ -547,6 +547,26 @@ bool cCommandProcessor::CmdIdle(cCommand &cmd) {
     return true;
 }
 
+class cMessageCallback : public cMainThreadLock::cCallback {
+    eMessageType Type;
+    const char *s;
+    int Seconds;
+    virtual int Callback();
+public:
+    eKeys Message(eMessageType Type, const char *s, int Seconds = 0);
+};
+
+int cMessageCallback::Callback() {
+    return Skins.Message(Type, s, Seconds);				
+}
+
+eKeys cMessageCallback::Message(eMessageType _Type, const char *_s, int _Seconds) {
+    Type = _Type;
+    s = _s;
+    Seconds = _Seconds;
+    return (eKeys)CallCallback();
+}
+
 bool cCommandProcessor::CmdMessage(cCommand &cmd) {
     /*
     MESSAGE [-info|-warn|-error] -queue [-timeout #] [-seconds #] message
@@ -634,27 +654,25 @@ bool cCommandProcessor::CmdMessage(cCommand &cmd) {
         }
     } else {
         int k=kNone;
-        cMainThreadLock Lock;
+        cMessageCallback Callback;
 
-        Lock.LockMainThread();
         switch (mode) {
         case status:
-            k=Skins.Message(mtStatus,cmd.GetArg(0),0);
+            k=Callback.Message(mtStatus,cmd.GetArg(0),0);
             break;
         case statusclear:
-            k=Skins.Message(mtStatus,NULL,0);
+            k=Callback.Message(mtStatus,NULL,0);
             break;
         case info:
-            k=Skins.Message(mtInfo,cmd.GetArg(0),seconds);
+            k=Callback.Message(mtInfo,cmd.GetArg(0),seconds);
             break;
         case warn:
-            k=Skins.Message(mtWarning,cmd.GetArg(0),seconds);
+            k=Callback.Message(mtWarning,cmd.GetArg(0),seconds);
             break;
         case error:
-            k=Skins.Message(mtError,cmd.GetArg(0),seconds);
+            k=Callback.Message(mtError,cmd.GetArg(0),seconds);
             break;
         }
-        Lock.UnlockMainThread();
 
         if (mode!=status && mode!=statusclear) {
             if (k != -1)
@@ -1017,7 +1035,7 @@ bool cCommandProcessor::CmdEditIntItemGetValue(cCommand &cmd, cOsdServerMenuEdit
 
     char str[20];
     sprintf(str, "%i", value);
-    Connection->ReplyTextGetValue(false, str);
+    Connection->ReplyTextGetValue(true, str);
     
     return true;
 }
