@@ -261,7 +261,7 @@ void cOsdServerMenu::Show() {
 void cOsdServerMenu::GetCurrent(int &cur, cString &curs) {
     cur = current;
     cOsdServerMenuItem *o = menuitems.Get(cur);
-    curs = o ? o->Name() : NULL;
+    curs = o ? o->Name() : cString();
 }
 
 void cOsdServerMenu::SetCurrent(int cur) {
